<!-- do not remove -->

## 0.1.1

### Bugs Squashed

- Saved OAuth credentials refresh with invalid widened scopes ([#1](https://github.com/AnswerDotAI/fastgws/issues/1))


## 0.1.0

- Initial release

